@@ -25,7 +25,7 @@ sub usage_desc {
 sub description {
     my $desc;
     $desc .= ucfirst(abstract) . ".\n";
-    $desc .= "\t<infiles> are paths to blocked fasta files, .fas.gz is supported.\n";
+    $desc .= "\t<infiles> are blocked fasta files, .fas.gz is supported.\n";
     return $desc;
 }
 
