@@ -1,7 +1,11 @@
 package App::Fasops::Command::replace;
+use strict;
+use warnings;
+use autodie;
 
 use App::Fasops -command;
-use App::Fasops::Common qw(:all);
+use App::RL::Common;
+use App::Fasops::Common;
 
 use constant abstract => 'replace headers from a blocked fasta';
 
@@ -45,7 +49,7 @@ sub validate_args {
 sub execute {
     my ( $self, $opt, $args ) = @_;
 
-    my $replace = read_replaces( $args->[1] );
+    my $replace = App::Fasops::Common::read_replaces( $args->[1] );
 
     #print "$_\n" for keys %{$replace};
 
@@ -67,7 +71,7 @@ sub execute {
                 $line = $in_fh->getline;
             }
             if ( ( $line eq '' or $line =~ /^\s+$/ ) and $content ne '' ) {
-                my $info_of = parse_block_header($content);
+                my $info_of = App::Fasops::Common::parse_block_header($content);
                 $content = '';
 
                 my @ori_names = keys %{$info_of};
@@ -76,7 +80,7 @@ sub execute {
 
                 if ( @replace_names == 0 ) {    # block untouched
                     for my $header (@ori_names) {
-                        printf {$out_fh} ">%s\n", encode_header( $info_of->{$header} );
+                        printf {$out_fh} ">%s\n", App::RL::Common::encode_header( $info_of->{$header} );
                         printf {$out_fh} "%s\n",  $info_of->{$header}{seq};
                     }
                     print {$out_fh} "\n";
@@ -90,7 +94,7 @@ sub execute {
                                 printf {$out_fh} "%s\n",  $info_of->{$header}{seq};
                             }
                             else {
-                                printf {$out_fh} ">%s\n", encode_header( $info_of->{$header} );
+                                printf {$out_fh} ">%s\n", App::RL::Common::encode_header( $info_of->{$header} );
                                 printf {$out_fh} "%s\n",  $info_of->{$header}{seq};
                             }
                         }
@@ -100,7 +104,7 @@ sub execute {
                 else {
                     Carp::carp "Don't support multiply records in one block. @replace_names\n";
                     for my $header (@ori_names) {
-                        printf {$out_fh} ">%s\n", encode_header( $info_of->{$header} );
+                        printf {$out_fh} ">%s\n", App::RL::Common::encode_header( $info_of->{$header} );
                         printf {$out_fh} "%s\n",  $info_of->{$header}{seq};
                     }
                     print {$out_fh} "\n";
